@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #ifndef QUICKBUTTONS_CONFIG_H
@@ -22,7 +17,7 @@ class QuickButtons_Config : public QWidget, public KonviSettingsPage, private Ui
   Q_OBJECT
 
   public:
-    explicit QuickButtons_Config(QWidget* parent, const char* name=NULL);
+    explicit QuickButtons_Config(QWidget* parent, const char* name=nullptr);
     ~QuickButtons_Config() override;
 
     void saveSettings() override;
@@ -41,13 +36,16 @@ class QuickButtons_Config : public QWidget, public KonviSettingsPage, private Ui
     void addEntry();
     void removeEntry();
 
-  protected:
+  private:
     void setButtonsListView(const QStringList &buttonList);
 
+  private:
     bool m_newItemSelected;
 
     QStringList m_oldButtonList;
     QStringList currentButtonList();
+
+    Q_DISABLE_COPY(QuickButtons_Config)
 };
 
 #endif
