@@ -139,7 +139,6 @@ namespace Konversation
             bool accept             = false,
                  abort              = false,
                  clear              = false,
-                 info               = false,
                  open               = false,
                  openLocation       = false,
                  resend             = false,
@@ -163,9 +162,6 @@ namespace Konversation
 
                     clear  |= (status >= Transfer::Done);
 
-                    info   |= (type == Transfer::Send ||
-                        status == Transfer::Done);
-
                     open   |= (type == Transfer::Send ||
                         status == Transfer::Done);
 
@@ -519,4 +515,4 @@ namespace Konversation
     }
 }
 
-
+#include "moc_transferpanel.cpp"
