@@ -23,7 +23,7 @@
 #include "viewcontainer.h"
 #include "outputfilterresolvejob.h"
 #include "konversation_log.h"
-#ifdef HAVE_QCA2
+#if HAVE_QCA2
 #include "cipher.h"
 #endif
 
@@ -1265,11 +1265,7 @@ namespace Konversation
 
         if (!input.parameter.isEmpty() && serverGroupId != -1)
         {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            const QStringList list = input.parameter.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
             const QStringList list = input.parameter.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
             for (const QString& parameter : list) {
                 // Try to remove current pattern.
@@ -1675,12 +1671,8 @@ namespace Konversation
 
     OutputFilterResult OutputFilter::command_setkey(const OutputFilterInput& input)
     {
-        #ifdef HAVE_QCA2
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList parms = input.parameter.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
+        #if HAVE_QCA2
         QStringList parms = input.parameter.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
         if (parms.count() == 1 && !input.destination.isEmpty())
             parms.prepend(input.destination);
@@ -1718,12 +1710,8 @@ namespace Konversation
 
     OutputFilterResult OutputFilter::command_keyx(const OutputFilterInput& input)
     {
-        #ifdef HAVE_QCA2
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList parms = input.parameter.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
+        #if HAVE_QCA2
         QStringList parms = input.parameter.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
         if (parms.isEmpty() && !input.destination.isEmpty())
             parms.prepend(input.destination);
@@ -2079,6 +2067,7 @@ namespace Konversation
     }
 }
 
+#include "moc_outputfilter.cpp"
 
 // kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
 // vim: set et sw=4 ts=4 cino=l1,cs,U1:
