@@ -1,17 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  serverison.h  -  Class to give a list of all the nicks known to the
-                   watchednick list that are on this server.  There is
-                   one instance of this class for each Server object.
-  begin:     Fri Sep 03 2004
-  copyright: (C) 2004 by John Tapsell
-  email:     john@geola.co.uk
+    SPDX-FileCopyrightText: 2004 John Tapsell <john@geola.co.uk>
 */
 
 /**
@@ -28,6 +18,12 @@
 
 class Server;
 
+
+/**
+ * Class to give a list of all the nicks known to the
+ * watchednick list that are on this server.  There is
+ * one instance of this class for each Server object.
+ */
 class ServerISON : public QObject
 {
     Q_OBJECT
@@ -51,11 +47,17 @@ class ServerISON : public QObject
         QStringList getISONList();
 
     private Q_SLOTS:
-        void nickInfoChanged(Server* server, const NickInfoPtr nickInfo);
+        void nickInfoChanged(Server* server, const NickInfoPtr &nickInfo);
         void slotServerGroupsChanged();
         void slotChannelMembersChanged(Server* server, const QString& channelName, bool joined, bool parted, const QString& nickname);
         void slotChannelJoinedOrUnjoined(Server* server, const QString& channelName, bool joined);
 
+    private:
+        /**
+         * Rebuilds list of nicks to watch whenever a preferences change occurs (whenever m_ISONLIst_invalid is true).
+         */
+        void recalculateAddressees();
+
     private:
         /// A pointer to the server we are a member of.
         Server* m_server;
@@ -67,10 +69,5 @@ class ServerISON : public QObject
         QStringList m_ISONList;
         /// If this is true, then we need to call recalculateAddressee before returning m_ISONList
         bool m_ISONList_invalid;
-        /**
-         * Rebuilds list of nicks to watch whenever a preferences change occurs (whenever m_ISONLIst_invalid is true).
-         */
-        void recalculateAddressees();
-
 };
 #endif
