@@ -18,6 +18,7 @@
 #include "serverlistdialog.h"
 #include "identitydialog.h"
 #include "notificationhandler.h"
+#include "launcherentryhandler.h"
 #include "irccharsets.h"
 #include "connectionmanager.h"
 #include "awaymanager.h"
@@ -26,7 +27,6 @@
 
 #include <QMenuBar>
 
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <QAction>
 #include <KToggleAction>
@@ -45,11 +45,17 @@
 #include <KShortcutsDialog>
 #include <KStandardShortcut>
 #include <KNotifyConfigWidget>
-#include <KGlobalAccel>
 #include <KStartupInfo>
 
+#include "config-konversation.h"
+
+#if HAVE_KGLOBALACCEL
+#include <KGlobalAccel>
+#endif
+
 MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
 {
+    setStateConfigGroup(QStringLiteral("MainWindow"));
     IrcContextMenus::setupUi(this);
 
     m_hasDirtySettings = false;
@@ -68,6 +74,8 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
 
     // Set up view container
     connect(Application::instance(), &Application::appearanceChanged, m_viewContainer, &ViewContainer::updateAppearance);
+    connect(Application::instance(), &Application::appearanceChanged, m_viewContainer, &ViewContainer::setUnseenEventsNotification);
+
     connect(Application::instance(), &Application::serverGroupsChanged,
             m_viewContainer, &ViewContainer::updateViews);
     connect(m_viewContainer, &ViewContainer::autoJoinToggled,
@@ -83,6 +91,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     connect(this, &MainWindow::triggerRememberLines, m_viewContainer, &ViewContainer::insertRememberLines);
     connect(this, &MainWindow::cancelRememberLine, m_viewContainer, &ViewContainer::cancelRememberLine);
     connect(this, &MainWindow::insertMarkerLine, m_viewContainer, &ViewContainer::insertMarkerLine);
+    connect(this, &MainWindow::resetFrontViewUnseenEventsCount, m_viewContainer, &ViewContainer::resetFrontViewUnseenEventsCount);
 
     // Set up status bar
     m_statusBar = new Konversation::StatusBar(this);
@@ -288,7 +297,10 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     action->setEnabled(false);
     connect(action, &QAction::triggered, m_viewContainer, &ViewContainer::showNextActiveView);
     actionCollection()->addAction(QStringLiteral("next_active_tab"), action);
+
+#if HAVE_KGLOBALACCEL
     KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>());
+#endif
 
     if (Preferences::self()->tabPlacement()==Preferences::Left)
     {
@@ -388,11 +400,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     selectAction->setEnabled(false);
     selectAction->setText(i18n("Set Encoding"));
     selectAction->setIcon(QIcon::fromTheme(QStringLiteral("character-set")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
     connect(selectAction, &KSelectAction::indexTriggered, m_viewContainer, &ViewContainer::changeViewCharset);
-#else
-    connect(selectAction, QOverload<int>::of(&KSelectAction::triggered), m_viewContainer, &ViewContainer::changeViewCharset);
-#endif
     actionCollection()->addAction(QStringLiteral("tab_encoding"), selectAction);
 
     for (uint i = 1; i <= 10; ++i)
@@ -538,7 +546,10 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     action->setText(i18n("Show/Hide Konversation"));
     connect(action, &QAction::triggered, this, &MainWindow::toggleVisibility);
     actionCollection()->addAction(QStringLiteral("toggle_mainwindow_visibility"), action);
+
+#if HAVE_KGLOBALACCEL
     KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>());
+#endif
 
     action=new KToggleAction(this);
     action->setEnabled(true);
@@ -717,6 +728,7 @@ bool MainWindow::event(QEvent* e)
     }
     else if (e->type() == QEvent::WindowActivate)
     {
+        Q_EMIT resetFrontViewUnseenEventsCount();
         Q_EMIT endNotification();
         Q_EMIT cancelRememberLine();
     }
@@ -963,3 +975,5 @@ void MainWindow::activateRaiseAndMoveToDesktop(MoveToDesktopMode moveToDesktop)
         KWindowSystem::activateWindow(winId());
     }
 }
+
+#include "moc_mainwindow.cpp"
