@@ -121,7 +121,7 @@ QPixmap LedIconEngine::pixmap(const QSize &size, QIcon::Mode mode, QIcon::State
 
 QIconEngine* LedIconEngine::clone() const
 {
-    LedIconEngine* newEngine = new LedIconEngine(m_color, m_state);
+    auto* newEngine = new LedIconEngine(m_color, m_state);
 
     return newEngine;
 }
@@ -296,4 +296,4 @@ QIcon Images::getHighlightsLed() const
         return m_highlightsLedOn;
 }
 
-
+#include "moc_images.cpp"
