@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005-2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005-2006 Eike Hein <hein@kde.org>
 */
 
 #ifndef IMAGES_H
@@ -15,7 +10,6 @@
 
 // Qt
 #include <QIcon>
-#include <QPixmap>
 #include <QObject>
 
 class NickIconSet;
@@ -46,24 +40,25 @@ class Images : public QObject
         Images();
         ~Images() override;
 
-        QIcon getLed(const QColor& col, bool state = true);
+        QIcon getLed(const QColor& col, bool state = true) const;
 
-        QIcon getServerLed(bool state);
-        QIcon getSystemLed(bool state);
-        QIcon getMsgsLed(bool state);
-        QIcon getPrivateLed(bool state);
-        QIcon getEventsLed();
-        QIcon getNickLed();
-        QIcon getHighlightsLed();
+        QIcon getServerLed(bool state) const;
+        QIcon getSystemLed(bool state) const;
+        QIcon getMsgsLed(bool state) const;
+        QIcon getPrivateLed(bool state) const;
+        QIcon getEventsLed() const;
+        QIcon getNickLed() const;
+        QIcon getHighlightsLed() const;
 
         QIcon getNickIcon(NickPrivilege privilege,bool isAway=false) const;
         QIcon getNickIconAwayOverlay() const;
         int getNickIconSize() const;
         void initializeNickIcons();
 
-    protected:
+    private:
         void initializeLeds();
 
+    private:
         QIcon m_serverLedOn;
         QIcon m_serverLedOff;
         QIcon m_systemLedOn;
