@@ -239,7 +239,11 @@ public:
     QStringList formats() const override;
 
 protected:
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     QVariant retrieveData(const QString &mimeType, QVariant::Type type) const override;
+#else
+    QVariant retrieveData(const QString &mimeType, QMetaType type) const override;
+#endif
 
 private:
     mutable QTextDocumentFragment fragment;
@@ -252,8 +256,11 @@ QStringList IrcViewMimeData::formats() const
     else
         return QMimeData::formats();
 }
-
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 QVariant IrcViewMimeData::retrieveData(const QString &mimeType, QVariant::Type type) const
+#else
+QVariant IrcViewMimeData::retrieveData(const QString &mimeType, QMetaType type) const
+#endif
 {
     if (!fragment.isEmpty())
     {
@@ -2460,3 +2467,4 @@ QDebug operator<<(QDebug d, const QTextBlock &b)
 }
 
 #include "ircview.moc"
+#include "moc_ircview.cpp"
